@@ -20,11 +20,16 @@ from __future__ import annotations
 from collections.abc import Iterable
 from functools import cached_property
 from pathlib import Path
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 from airflow.providers.common.compat.notifier import BaseNotifier
 from airflow.providers.smtp.hooks.smtp import SmtpHook
 
+from tests_common.test_utils.version_compat import AIRFLOW_V_3_1_PLUS
+
+if TYPE_CHECKING:
+    from airflow.sdk import Context
+
 
 class SmtpNotifier(BaseNotifier):
     """
@@ -34,7 +39,7 @@ class SmtpNotifier(BaseNotifier):
 
     .. code-block:: python
 
-        EmptyOperator(task_id="task", on_failure_callback=SmtpNotifier(from_email=None, to="myemail@myemail.com"))
+        EmptyOperator(task_id="task", on_failure_callback=SmtpNotifier(from_email=None, to="my@mail.com"))
 
         EmptyOperator(
             task_id="task",
@@ -77,10 +82,16 @@ class SmtpNotifier(BaseNotifier):
         mime_charset: str = "utf-8",
         custom_headers: dict[str, Any] | None = None,
         smtp_conn_id: str = SmtpHook.default_conn_name,
+        auth_type: str = "basic",
         *,
         template: str | None = None,
+        **kwargs,
     ):
-        super().__init__()
+        if AIRFLOW_V_3_1_PLUS:
+            #  Support for passing context was added in 3.1.0
+            super().__init__(**kwargs)
+        else:
+            super().__init__()
         self.smtp_conn_id = smtp_conn_id
         self.from_email = from_email
         self.to = to
@@ -92,6 +103,7 @@ class SmtpNotifier(BaseNotifier):
         self.custom_headers = custom_headers
         self.subject = subject
         self.html_content = html_content
+        self.auth_type = auth_type
         if self.html_content is None and template is not None:
             self.html_content = self._read_template(template)
 
@@ -102,21 +114,20 @@ class SmtpNotifier(BaseNotifier):
     @cached_property
     def hook(self) -> SmtpHook:
         """Smtp Events Hook."""
-        return SmtpHook(smtp_conn_id=self.smtp_conn_id)
+        return SmtpHook(smtp_conn_id=self.smtp_conn_id, auth_type=self.auth_type)
 
-    def notify(self, context):
-        """Send a email via smtp server."""
+    def _build_email_content(self, smtp: SmtpHook, context: Context):
         fields_to_re_render = []
         if self.from_email is None:
-            if self.hook.from_email is not None:
-                self.from_email = self.hook.from_email
+            if smtp.from_email is not None:
+                self.from_email = smtp.from_email
             else:
                 raise ValueError("You should provide `from_email` or define it in the connection")
             fields_to_re_render.append("from_email")
         if self.subject is None:
             smtp_default_templated_subject_path: str
-            if self.hook.subject_template:
-                smtp_default_templated_subject_path = self.hook.subject_template
+            if smtp.subject_template:
+                smtp_default_templated_subject_path = smtp.subject_template
             else:
                 smtp_default_templated_subject_path = (
                     Path(__file__).parent / "templates" / "email_subject.jinja2"
@@ -125,8 +136,8 @@ class SmtpNotifier(BaseNotifier):
             fields_to_re_render.append("subject")
         if self.html_content is None:
             smtp_default_templated_html_content_path: str
-            if self.hook.html_content_template:
-                smtp_default_templated_html_content_path = self.hook.html_content_template
+            if smtp.html_content_template:
+                smtp_default_templated_html_content_path = smtp.html_content_template
             else:
                 smtp_default_templated_html_content_path = (
                     Path(__file__).parent / "templates" / "email.html"
@@ -134,10 +145,32 @@ class SmtpNotifier(BaseNotifier):
             self.html_content = self._read_template(smtp_default_templated_html_content_path)
             fields_to_re_render.append("html_content")
         if fields_to_re_render:
-            jinja_env = self.get_template_env(dag=context["dag"])
+            jinja_env = self.get_template_env(dag=context.get("dag"))
             self._do_render_template_fields(self, fields_to_re_render, context, jinja_env, set())
-        with self.hook as smtp:
-            smtp.send_email_smtp(
+
+    def notify(self, context: Context):
+        """Send a email via smtp server."""
+        with self.hook as smtp_hook:
+            self._build_email_content(smtp_hook, context)
+            smtp_hook.send_email_smtp(
+                smtp_conn_id=self.smtp_conn_id,
+                from_email=self.from_email,
+                to=self.to,
+                subject=self.subject,
+                html_content=self.html_content,
+                files=self.files,
+                cc=self.cc,
+                bcc=self.bcc,
+                mime_subtype=self.mime_subtype,
+                mime_charset=self.mime_charset,
+                custom_headers=self.custom_headers,
+            )
+
+    async def async_notify(self, context: Context):
+        """Send a email via smtp server (async)."""
+        async with self.hook as smtp_hook:
+            self._build_email_content(smtp_hook, context)
+            await smtp_hook.asend_email_smtp(
                 smtp_conn_id=self.smtp_conn_id,
                 from_email=self.from_email,
                 to=self.to,
